@@ -95,15 +95,15 @@ class PRDescriptionGenerator:
             pull_request_desc,
             user,
         ):
-            file_descs.extend(file_review)
+            file_descs.append(file_review)
 
         if len(file_descs) > 1:
             prompt = MERGE_PR_DESCRIPTION_PROMPT.format(DESCS=json.dumps(file_descs))
             resp, usage = self.provider.chat_completion(prompt, user=user)
+            self.total_usage = self.provider.update_usage(self.total_usage, usage)
             desc = parser.extract_code_from_markdown(resp)
         else:
             desc = parser.extract_code_from_markdown(file_descs[0])
-        self.total_usage = self.provider.update_usage(self.total_usage, usage)
 
         return desc
 
@@ -120,7 +120,7 @@ class PRDescriptionGenerator:
                 CODE_DIFF="",
             )
         )
-
+        diff_parts = []
         for file in pull_request_files:
             patch_details = file.get("patch")
             filename = file.get("filename", "")
@@ -129,13 +129,16 @@ class PRDescriptionGenerator:
                 filename.split(".")[-1] not in parser.EXCLUDED_FILETYPES
                 and patch_details is not None
             ):
-                temp_prompt = (
-                    combined_diff_data
-                    + f"\n---->\nFile Name: {filename}\nPatch Details: \n{patch_details}"
+                diff_parts.append(
+                    f"\n---->\nFile Name: {filename}\nPatch Details: \n{patch_details}"
                 )
 
-                if available_tokens - self.provider.get_token_count(temp_prompt) > 0:
-                    combined_diff_data = temp_prompt
+                if (
+                    available_tokens
+                    - self.provider.get_token_count("".join(diff_parts))
+                    > 0
+                ):
+                    combined_diff_data = "".join(diff_parts)
                     continue
 
                 yield self._process_file_chunk(
@@ -144,13 +147,13 @@ class PRDescriptionGenerator:
                     pull_request_desc,
                     user,
                 )
-                combined_diff_data = (
+                diff_parts = [
                     f"\n---->\nFile Name: {filename}\nPatch Details: {patch_details}"
-                )
+                ]
 
-        if combined_diff_data:
+        if diff_parts:
             yield self._process_file_chunk(
-                combined_diff_data,
+                "".join(diff_parts),
                 pull_request_title,
                 pull_request_desc,
                 user,
@@ -181,4 +184,4 @@ class PRDescriptionGenerator:
             DESC=desc,
         )
         resp, usage = self.provider.chat_completion_with_json(prompt, user=user)
-        return resp, usage
+        return resp, usage, self.provider.model
