@@ -1,11 +1,31 @@
 CODE_REVIEW_SYSTEM_PROMPT = """
-As a senior software developer reviewing code submissions, provide thorough, constructive feedback and suggestions for improvements. Consider best practices, error handling, performance, readability, and maintainability. Offer objective and respectful reviews that help developers enhance their skills and code quality. Use your expertise to provide comprehensive feedback without asking clarifying questions.
+You are an expert code reviewer. Provide thorough, constructive feedback on code submissions, considering best practices, error handling, performance, readability, maintainability, and security. Be objective, respectful, and focus on helping developers improve their code quality.
+
+Review Process:
+1. Analyze provided context and diff to understand changes.
+2. Evaluate changes for correctness, performance, security, and maintainability.
+3. Identify improvement opportunities, considering best practices and patterns.
+4. Assess error handling and potential edge cases.
+5. Consider testing implications and documentation needs.
+6. Analyze impact on dependencies and overall system.
+7. Identify potential technical debt and future-proofing concerns.
+8. Summarize findings and prioritize feedback.
+
+Provide specific feedback with accurate references to the provided content. 
+Be thorough and strict in your review, but don't ask clarifying questions.
+
+Focus on new and modified code while considering existing context.
+Provide specific feedback with accurate file paths and line numbers.
+Be thorough and strict, but don't ask clarifying questions.
 """
 
 CODE_REVIEW_PROMPT = """
 Provide a concise, actionable code review for the given pull request. Generate a JSON object with the following structure:
 {{
   "code_quality_percentage": <0_TO_100>,
+  "security_score": <0_TO_100>,
+  "compliance_score": <0_TO_100>,
+  "performance_score": <0_TO_100>,
   "review": [
     {{
       "category": "<ISSUE_CATEGORY>",
@@ -21,6 +41,7 @@ Provide a concise, actionable code review for the given pull request. Generate a
       "end_line": <ENDING_LINE_NUMBER>,
       "sentiment": "positive|negative|neutral",
       "severity": <1_TO_10>,
+      "line_prefix": "CONTEXT|REMOVED|UPDATED",
       "type": "general|performance|security|refactoring|best_practices|duplication|maintainability|scalability|error_handling|resource_management|concurrency|dependencies|compatibility|accessibility|localization|efficiency|readability|naming",
       "technical_debt": "<POTENTIAL_FUTURE_ISSUES>|empty",
       "alternatives": "<ALTERNATIVE_SOLUTIONS>|empty"
@@ -40,6 +61,12 @@ When reviewing code and calculating the code quality percentage, consider:
 8. Error handling: Are errors and edge cases properly managed?
 9. Modularity: Is the code organized into logical, reusable components?
 10. Scalability: Can the code handle increased load or data volume?
+11. Compliance: Does the code adhere to relevant standards and regulations?
+12. Container and infrastructure best practices: If applicable, are container and IaC files following best practices?
+13. AI/ML considerations: If applicable, are there concerns about bias, fairness, or explainability?
+14. Accessibility: Does the code consider accessibility standards?
+15. Internationalization: Is the code prepared for multiple languages and locales?
+
 
 Score each parameter 1-10, then calculate the overall percentage.
 
@@ -47,6 +74,7 @@ Score each parameter 1-10, then calculate the overall percentage.
 - Provide specific feedback with file paths and line numbers
 - Use markdown for code snippets. Make sure all code is following the original indentations.
 - Merge duplicate feedback
+- Check for OWASP Top 10 vulnerabilities.
 - Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities, performance issues, scalability concerns, refactoring opportunities, and code duplication
 - If no issues found: {{"review": []}}
 
@@ -73,6 +101,9 @@ Example:
 7. Identify code duplication and suggest refactoring.
 8. Prioritize issues based on impact. Be strict; don't let issues slide.
 9. If no issues found: {{"review": []}}
+10. Make sure suggested_code and current_code return full functional block of code. We will use that to overwrite the current_code.
+
+{CUSTOM_RULES}
 
 ## Additional Considerations:
 - Language-specific best practices and common pitfalls
@@ -80,6 +111,9 @@ Example:
 - Potential performance implications
 - Security vulnerabilities introduced by changes
 - Opportunities for code reuse and design pattern application
+- Compliance with relevant standards and regulations
+- Container and infrastructure best practices (if applicable)
+- Accessibility and internationalization issues
 
 Provide concrete examples or code snippets when suggesting improvements.
 
@@ -87,93 +121,6 @@ Provide concrete examples or code snippets when suggesting improvements.
 ```{CODE_DIFF}```
 """
 
-FILE_CODE_REVIEW_PROMPT = """
-Provide a concise, actionable code review for the given pull request. Generate a JSON object with the following structure:
-{{
-  "code_quality_percentage": <0_TO_100>,
-  "review": [
-    {{
-      "category": "<ISSUE_CATEGORY>",
-      "description": "<CONCISE_ISSUE_DESCRIPTION>",
-      "impact": "critical|high|medium|low|trivial",
-      "priority": "critical|high|medium|low",
-      "rationale": "<DETAILED_EXPLANATION>",
-      "recommendation": "<SPECIFIC_IMPROVEMENT_SUGGESTION>",
-      "current_code": "<PROBLEMATIC_CODE_SNIPPET>",
-      "suggested_code": "<IMPROVED_CODE_SNIPPET>",
-      "file_path": "<FULL_FILE_PATH>",
-      "start_line": <STARTING_LINE_NUMBER>,
-      "end_line": <ENDING_LINE_NUMBER>,
-      "sentiment": "positive|negative|neutral",
-      "severity": <1_TO_10>,
-      "type": "general|performance|security|refactoring|best_practices|duplication|maintainability|scalability|error_handling|resource_management|concurrency|dependencies|compatibility|accessibility|localization|efficiency|readability|naming",
-      "technical_debt": "<POTENTIAL_FUTURE_ISSUES>|empty",
-      "alternatives": "<ALTERNATIVE_SOLUTIONS>|empty"
-    }}
-  ]
-}}
-
-## Code Quality Parameters:
-When reviewing code and calculating the code quality percentage, consider:
-1. Correctness: Does the code function as intended?
-2. Security: Are there any potential vulnerabilities?
-3. Performance: Is the code optimized for speed and resource usage?
-4. Maintainability: Is the code easy to understand and modify?
-5. Testability: Can the code be easily tested?
-6. Code style: Does it adhere to established coding standards?
-7. Documentation: Is the code well-commented and documented?
-8. Error handling: Are errors and edge cases properly managed?
-9. Modularity: Is the code organized into logical, reusable components?
-10. Scalability: Can the code handle increased load or data volume?
-
-Score each parameter 1-10, then calculate the overall percentage.
-
-## Guidelines:
-- Provide specific feedback with file paths and line numbers
-- Use markdown for code snippets. Make sure all code is following the original indentations.
-- Merge duplicate feedback
-- Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities, performance issues, scalability concerns, refactoring opportunities, and code duplication
-- If no issues found: {{"review": []}}
-
-## Patch Data Format:
-- First column: Line number in the context
-- Second column: Change type
-  '[CONTEXT]': Unchanged line providing context
-  '[REMOVED]': Line removed from the original code
-  '[UPDATED]': Line updated or added in the new code
-- Remaining columns: Code content
-
-Example:
-[FILE_START] auth.py
-[LINE 23] [CONTEXT] def register_user(username, password):
-[LINE 24] [REMOVED]     hashed_password = md5(password.encode()).hexdigest()
-[LINE 24] [UPDATED]     hashed_password = bcrypt.hashpw(password.encode(), bcrypt.gensalt())
-[FILE_END]
-
-## Review Guidelines:
-1. Analyze [REMOVED] and [UPDATED] lines for impact on code quality and functionality.
-2. Use [CONTEXT] lines for understanding surrounding code.
-3. Provide specific feedback with file paths and line numbers.
-4. Suggest improvements for [UPDATED] lines in 'suggested_code'.
-5. Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities, performance issues, scalability, refactoring opportunities, and code duplication.
-6. Consider: overall system architecture, coding standards, best practices, dependencies, performance impact, and security implications.
-7. Identify code duplication and suggest refactoring.
-8. Prioritize issues based on impact. Be strict; don't let issues slide.
-9. If no issues found: {{"review": []}}
-
-## Additional Considerations:
-- Language-specific best practices and common pitfalls
-- Impact of changes on project dependencies
-- Potential performance implications
-- Security vulnerabilities introduced by changes
-- Opportunities for code reuse and design pattern application
-
-Provide concrete examples or code snippets when suggesting improvements.
-
-## File PATCH Data:
-```{FILE_PATCH}```
-"""
-
 
 PR_REVIEW_EVALUATION_PROMPT = """
 
@@ -222,6 +169,7 @@ Score each parameter 1-10, then calculate the overall percentage.
 - Provide specific feedback with file paths and line numbers
 - Use markdown for code snippets. Make sure all code is following the original indentations.
 - Merge duplicate feedback
+- Check for OWASP Top 10 vulnerabilities.
 - Examine: syntax/logic errors, resource leaks, race conditions, security vulnerabilities, performance issues, scalability concerns, refactoring opportunities, and code duplication
 - If no issues found: {{"review": []}}
 
